@@ -298,7 +298,16 @@ void KDEPlatformFileDialogHelper::initializeDialog()
         const QStringList mimeFilters = options()->mimeTypeFilters();
         const QStringList nameFilters = options()->nameFilters();
         if (!mimeFilters.isEmpty()) {
-            dialog->m_fileWidget->setMimeFilter(mimeFilters);
+            QString defaultMimeFilter;
+            if (options()->acceptMode() == QFileDialogOptions::AcceptSave) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+                defaultMimeFilter = options()->initiallySelectedMimeTypeFilter();
+#endif
+                if (defaultMimeFilter.isEmpty()) {
+                    defaultMimeFilter = mimeFilters.at(0);
+                }
+            }
+            dialog->m_fileWidget->setMimeFilter(mimeFilters, defaultMimeFilter);
 
             if ( mimeFilters.contains( QStringLiteral("inode/directory") ) )
                 dialog->m_fileWidget->setMode( dialog->m_fileWidget->mode() | KFile::Directory );
@@ -306,9 +315,17 @@ void KDEPlatformFileDialogHelper::initializeDialog()
             dialog->m_fileWidget->setFilter(qt2KdeFilter(nameFilters));
         }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
+        if (!options()->initiallySelectedMimeTypeFilter().isEmpty()) {
+            selectMimeTypeFilter(options()->initiallySelectedMimeTypeFilter());
+        } else if (!options()->initiallySelectedNameFilter().isEmpty()) {
+            selectNameFilter(options()->initiallySelectedNameFilter());
+        }
+#else
         if (!options()->initiallySelectedNameFilter().isEmpty()) {
             selectNameFilter(options()->initiallySelectedNameFilter());
         }
+#endif
 
         // overwrite option
         if (options()->testOption(QFileDialogOptions::FileDialogOption::DontConfirmOverwrite)) {
